core.error — PyZMQ v2.1.1dev documentation

### Navigation

- index
- modules |
- next |
- previous |
- home|
- search|
- API »
- The PyZMQ API »

# core.error

## Module: `core.error`

Inheritance diagram for `zmq.core.error`:

0MQ Error classes and functions.

## Classes

### `NotDone`

class `zmq.core.error.` `NotDone`

  Bases: `zmq.core.error.ZMQBaseError`

  Raised when timeout is reached while waiting for 0MQ to finish with a Message

  See also

  `MessageTracker.wait`
    object for tracking when ZeroMQ is done
  `args`
  `message`

### `ZMQBaseError`

class `zmq.core.error.` `ZMQBaseError`

  Bases: `exceptions.Exception`

  Base exception class for 0MQ errors in Python.

  `args`
  `message`

### `ZMQBindError`

class `zmq.core.error.` `ZMQBindError`

  Bases: `zmq.core.error.ZMQBaseError`

  An error for `Socket.bind_to_random_port()`.

  See also

  `Socket.bind_to_random_port`

  `args`
  `message`

### `ZMQError`

class `zmq.core.error.` `ZMQError`

  Bases: `zmq.core.error.ZMQBaseError`

  Wrap an errno style error.

  Parameters : | error : int The ZMQ errno or None. If None, then `zmq_errno()` is called and used.

  `args`
  `message`

## Function

`zmq.core.error.` `strerror`(errnum)

  Return the error string given the error number.

### Navigation

- index
- modules |
- next |
- previous |
- home|
- search|
- API »
- The PyZMQ API »